@@ -33,13 +33,15 @@ class Categorise(CLIBase):
 
 
     def process(self):
-        #mkdir_p(self._cat)
+        mkdir_p(self._cat)
         # define the path
         currentDirectory = pathlib.Path('.')
 
         for currentFile in currentDirectory.iterdir():
             if self._cat in currentFile.stem:
                 print(currentFile)
+                path = Path(self._cat, currentFile)
+                print(path)
 
 #if __name__ == '__main__':
 #    app = Inventory()
